@@ -2,7 +2,7 @@
 /* The Pure main program. This is currently rather simplistic. See the README
    file and the man page for details. */
 
-/* Copyright (c) 2008-2017 by Albert Graef <aggraef@gmail.com>.
+/* Copyright (c) 2008-2018 by Albert Graef <aggraef@gmail.com>.
 
    The Pure main program is free software: you can redistribute it and/or
    modify it under the terms of the GNU General Public License as published by
@@ -96,12 +96,13 @@ using namespace std;
 #define PURELIB "/usr/local/lib/pure-" PACKAGE_VERSION
 #endif
 
-#define COPYRIGHT "Copyright (c) 2008-2017 by Albert Graef"
+#define COPYRIGHT "Copyright (c) 2008-2018 by Albert Graef"
 #define USAGE \
 "Usage:            pure [options ...] [-x] script [args ...]\n\
                   pure [options ...] [-b|-c|-i] [script ...] [-- args ...]\n\
 -b                Batch mode (execute given scripts and exit).\n\
 -c                Batch compilation (compile scripts to native binary).\n\
+--check           Syntax check only, do not actually execute scripts.\n\
 --ctags, --etags  Create a tags file in ctags (vi) or etags (emacs) format.\n\
 --disable=optname Disable source option (conditional compilation).\n\
 --eager-jit       Enable eager JIT compilation (LLVM 2.7 or later).\n\
@@ -527,7 +528,10 @@ main(int argc, char *argv[])
   int count = 0;
   bool batch = false, quiet = false, spiffy = true, force_interactive = false,
     want_prelude = true, have_prelude = false,
-    want_rcfile = true, want_editing = true;
+    want_rcfile = true;
+#ifdef HAVE_LIBREADLINE
+  bool want_editing = true;
+#endif
   string rcfile;
 #ifdef __MINGW32__
   string outname = "a.exe";
@@ -616,6 +620,10 @@ main(int argc, char *argv[])
 	batch = true; interp.tags = 1;
       } else if (strcmp(arg, "--etags") == 0) {
 	batch = true; interp.tags = 2;
+      } else if (strcmp(arg, "--check") == 0) {
+	// this works basically like tags mode, but only does a syntax check
+	// without generating any other output
+	batch = true; interp.tags = -1;
       } else if (strcmp(arg, "--texmacs") == 0)
 	interp.texmacs = true;
       else if (strcmp(arg, "--eager-jit") == 0)
@@ -625,7 +633,11 @@ main(int argc, char *argv[])
       else if (strcmp(arg, "--norc") == 0)
 	want_rcfile = false;
       else if (strcmp(arg, "--noediting") == 0)
+#ifdef HAVE_LIBREADLINE
 	want_editing = false;
+#else
+        ;
+#endif
       else if (strcmp(arg, "--nosymbolic") == 0)
 	interp.symbolic = false;
       else if (strcmp(arg, "--symbolic") == 0)
